==> piwigo-2.1.5.tbz: www/piwigo/language/en_UK/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Upgrade";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "This page proposes to upgrade the database from your Piwigo old version to the new version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).";
$lang['Upgrade from version %s to %s'] = "Upgrade from version %s to %s";
$lang['Statistics'] = "Statistics";
$lang['total upgrade time'] = "total upgrade time";
$lang['total SQL time'] = "total SQL time";
$lang['SQL queries'] = "SQL queries";
$lang['Upgrade informations'] = "Upgrade information";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "As a precaution, the following plugins have been deactivated. You must check for plugins upgrades before reactivating them:";
$lang['Only administrator can run upgrade: please sign in below.'] = "Only an administrator can run upgrade: please sign in below.";
$lang['You do not have access rights to run upgrade'] = "You do not have access rights to run upgrade";
$lang['All sub-categories of private categories become private'] = "All sub-categories of private categories become private";
$lang['User permissions and group permissions have been erased'] = "Users and groups permissions have been erased";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Only thumbnails prefix and webmaster mail address have been saved from previous configuration";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, before <b>?></b>, insert:';
?>

==> piwigo-2.3.3.tbz: www/piwigo/language/en_UK/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Upgrade";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "This page proposes to upgrade the database from your Piwigo old version to the new version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).";
$lang['Upgrade from version %s to %s'] = "Upgrade from version %s to %s";
$lang['Statistics'] = "Statistics";
$lang['total upgrade time'] = "total upgrade time";
$lang['total SQL time'] = "total SQL time";
$lang['SQL queries'] = "SQL queries";
$lang['Upgrade informations'] = "Upgrade information";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "As a precaution, the following plugins have been deactivated. You must check for plugins upgrades before reactivating them:";
$lang['Only administrator can run upgrade: please sign in below.'] = "Only an administrator can run upgrade: please sign in below.";
$lang['You do not have access rights to run upgrade'] = "You do not have access rights to run upgrade";
$lang['All sub-albums of private albums become private'] = "All sub-albums of private albums become private";
$lang['User permissions and group permissions have been erased'] = "Users and groups permissions have been erased";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Only thumbnails prefix and webmaster mail address have been saved from previous configuration";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, before <b>?></b>, insert:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:';
?>
